==> haskell-hspec-wai-0.9.0-32-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-wai
version: 0.9.0
id: hspec-wai-0.9.0-6NrBRTsb6DKDYFJ0mlYkCX
key: hspec-wai-0.9.0-6NrBRTsb6DKDYFJ0mlYkCX
license: MIT
copyright: (c) 2012-2014 Fujimura Daisuke,
           (c) 2014-2015 Simon Hengel
maintainer: Fujimura Daisuke <me@fujimuradaisuke.com>,
            Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-wai#readme
synopsis: Experimental Hspec support for testing WAI applications
description:
    Experimental Hspec support for testing WAI applications
category: Testing
author: Fujimura Daisuke <me@fujimuradaisuke.com>,
        Simon Hengel <sol@typeful.net>
exposed: True
indefinite: False
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck
hidden-modules: Test.Hspec.Wai.Util Paths_hspec_wai
abi: 8e9749ef2974c225f48e7d43f6af6f9d
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hspec-wai-0.9.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/hspec-wai-0.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/hspec-wai-0.9.0
hs-libraries: HShspec-wai-0.9.0-6NrBRTsb6DKDYFJ0mlYkCX
depends:
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9 base-4.10.1.0
    base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA bytestring-0.10.8.2
    case-insensitive-1.2.0.10-GwUFN11YDUS3aWErjHGiBw
    hspec-core-2.4.8-LVVcxoJgh1cHnmU659eKw8
    hspec-expectations-0.8.2-IgJxviRXjDtLn1BmxNwtah
    http-types-0.9.1-BnmUD9RxZRhHekChwpKApV
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj transformers-0.5.2.0
    wai-3.2.1.1-JM87vg9uknZGvXXydqppYS
    wai-extra-3.0.22.0-EiD10i66aan8PT2H41Ou1H
abi-depends: QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=8d659ba36825a86aa37a2316500bb35b
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=5a5696f2eea50c76cb741a2b4cb0b84c
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             case-insensitive-1.2.0.10-GwUFN11YDUS3aWErjHGiBw=925191f86667b41dcb51c4650e0bf4fb
             hspec-core-2.4.8-LVVcxoJgh1cHnmU659eKw8=9ff127da88e8c09cc06d2020b5ca0a19
             hspec-expectations-0.8.2-IgJxviRXjDtLn1BmxNwtah=5afe9736addd87df0f3d46c5877c97a9
             http-types-0.9.1-BnmUD9RxZRhHekChwpKApV=17904082cafa5b41bdd6c56cc1e99042
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             wai-3.2.1.1-JM87vg9uknZGvXXydqppYS=e59b573ecb4a53343d760a19fea60b09
             wai-extra-3.0.22.0-EiD10i66aan8PT2H41Ou1H=1bda66eb01539aa8a796b2246da6765c
haddock-interfaces: /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html: /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-wai-0.9.0-49-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-wai
version: 0.9.0
id: hspec-wai-0.9.0-8ZPBRq1DN3EGxgOliFUOuj
key: hspec-wai-0.9.0-8ZPBRq1DN3EGxgOliFUOuj
license: MIT
copyright: (c) 2012-2014 Fujimura Daisuke,
           (c) 2014-2015 Simon Hengel
maintainer: Fujimura Daisuke <me@fujimuradaisuke.com>,
            Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-wai#readme
synopsis: Experimental Hspec support for testing WAI applications
description:
    Experimental Hspec support for testing WAI applications
category: Testing
author: Fujimura Daisuke <me@fujimuradaisuke.com>,
        Simon Hengel <sol@typeful.net>
exposed: True
indefinite: False
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck
hidden-modules: Test.Hspec.Wai.Util Paths_hspec_wai
abi: 645bd22f42be14442959d5ad4f40184e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hspec-wai-0.9.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/hspec-wai-0.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/hspec-wai-0.9.0
hs-libraries: HShspec-wai-0.9.0-8ZPBRq1DN3EGxgOliFUOuj
depends:
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9 base-4.10.1.0
    base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA bytestring-0.10.8.2
    case-insensitive-1.2.0.11-6XUs0OYFV3wE0SFwF3qQ2a
    hspec-core-2.5.0-H7rLxB8210GpJ49ngT5i8
    hspec-expectations-0.8.2-IgJxviRXjDtLn1BmxNwtah
    http-types-0.9.1-6X2WIr2ON586RGGZSRTan8
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj transformers-0.5.2.0
    wai-3.2.1.2-L2G3elceofc1yhjOKmecqb
    wai-extra-3.0.22.0-K8NG3qWUot12wYOZjPCu7Q
abi-depends: QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=8d659ba36825a86aa37a2316500bb35b
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=5a5696f2eea50c76cb741a2b4cb0b84c
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             case-insensitive-1.2.0.11-6XUs0OYFV3wE0SFwF3qQ2a=d08ac5e9b3f9d5ae0bee3532b0fd2d5e
             hspec-core-2.5.0-H7rLxB8210GpJ49ngT5i8=5cdf361745a7c5d1ab16568a54e8846f
             hspec-expectations-0.8.2-IgJxviRXjDtLn1BmxNwtah=5afe9736addd87df0f3d46c5877c97a9
             http-types-0.9.1-6X2WIr2ON586RGGZSRTan8=f3cf44f811b734b379910c70c68230da
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             wai-3.2.1.2-L2G3elceofc1yhjOKmecqb=01d341254f1cf59b77299ea88d31ec1e
             wai-extra-3.0.22.0-K8NG3qWUot12wYOZjPCu7Q=4ef0a513a3847e87fe2cab4e6369c095
haddock-interfaces: /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html: /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
